===============================
bannock
===============================

.. image:: https://img.shields.io/travis/eddiejessup/bannock.svg
        :target: https://travis-ci.org/eddiejessup/bannock

.. image:: https://img.shields.io/pypi/v/bannock.svg
        :target: https://pypi.python.org/pypi/bannock


Agent-based simulations in confined environments

* Free software: BSD license
* Documentation: https://bannock.readthedocs.org.

Features
--------

* TODO
